@@ -10,12 +10,96 @@ from django_libs.tests.factories import UserFactory
 class ViewTestMixin(object):
     """Mixin that provides commonly tested assertions."""
 
+    def is_callable(self, method='get', data=None, message=None, kwargs=None,
+                    user=None, anonymous=False):
+        """
+        A shortcut for an assertion on status code 200 or 302.
+
+        :method: 'get' or 'post'. Default is 'get'.
+        :data: Post data or get data payload.
+        :message: Lets you override the assertion message.
+        :kwargs: Lets you override the view kwargs.
+        :user: If user argument is given, it logs it in first.
+        :anonymous: If True, it logs out the user first. Default is False
+
+        If no arguments are given, it makes the assertion according to the
+        current test situation.
+
+        """
+        if user:
+            self.login(user)
+        if anonymous:
+            self.client.logout()
+        if method.lower() == 'get':
+            resp = self.client.get(
+                self.get_url(view_kwargs=kwargs or self.get_view_kwargs()),
+                data=data or self.get_data_payload()
+            )
+            self.assertEqual(resp.status_code, 200, msg=(
+                message or
+                'If called with the correct data, the view should be callable.'
+                ' Got status code of {0}'.format(resp.status_code)))
+        elif method.lower() == 'post':
+            resp = self.client.post(
+                self.get_url(view_kwargs=kwargs or self.get_view_kwargs()),
+                data=data or self.get_data_payload()
+            )
+            self.assertEqual(resp.status_code, 302, msg=(
+                message or
+                'If posted with the correct data, the view should be callable.'
+                ' Got status code of {0}'.format(resp.status_code)))
+        else:
+            raise Exception('Not a valid request method: "{0}"'.format(method))
+        return resp
+
+    def is_not_callable(self, method='get', message=None, data=None,
+                        kwargs=None, user=None, anonymous=False):
+        """
+        A shortcut for a common assertion on a 404 status code.
+
+        :method: 'get' or 'post'. Default is 'get'.
+        :message: The message to display if the assertion fails
+        :data: Get data payload or post data.
+        :kwargs: View kwargs can be overridden. This is e.g. necessary if
+            you call is_not_callable for a deleted object, where the object.pk
+            was assigned in get_view_kwargs.
+        :user: If a user is given, it logs it in first.
+        :anonymous: If True, it logs out the user first. Default is False
+
+        If no arguments are given, it makes the assertion according to the
+        current test situation.
+
+        """
+        if user:
+            self.login(user)
+        if anonymous:
+            self.client.logout()
+        if method.lower() == 'get':
+            resp = self.client.get(
+                self.get_url(view_kwargs=kwargs or self.get_view_kwargs()),
+                data=data or self.get_data_payload()
+            )
+        elif method.lower() == 'post':
+            resp = self.client.post(
+                self.get_url(view_kwargs=kwargs or self.get_view_kwargs()),
+                data=data or self.get_data_payload()
+            )
+        else:
+            raise Exception('Not a valid request method: "{0}"'.format(method))
+        self.assertEqual(resp.status_code, 404, msg=(
+            message or
+            'If called with the wrong data, the view should not be callable'
+            ' Got status code of {0}'.format(resp.status_code)))
+        return resp
+
     def get_data_payload(self):
         """
         Returns a dictionairy providing GET data payload sent to the view.
 
         If the view expects request.GET data to include this, you can override
-        this method and return the proper data for the test."""
+        this method and return the proper data for the test.
+
+        """
         if hasattr(self, 'data_payload'):
             return self.data_payload
         return {}
